@@ -11,6 +11,8 @@ from flask import request
 from firebase_admin import auth as firebase_auth
 
 from .tracking import send_tracking_information
+from .log import adscale_log
+from .services import ServiceEnum
 
 rights_mapper = {
     'None': 0,
@@ -19,6 +21,8 @@ rights_mapper = {
     'Admin': 3
 }
 
+CLIENTS_KIND = 'base-clients'
+
 
 class IncorrectAccessRightsRouteImplementation(TypeError):
     pass
@@ -30,9 +34,7 @@ def check_access_rights(service: str,
                         pubsub_client: PubSubClient,
                         receive_rights_per_client: bool=False,
                         auth_enabled: bool=True,
-                        adscale_key: str=None,
-                        project: str=None,
-                        clients_kind='clients'
+                        project: str=None
                         ) -> Callable[[Callable], Callable]:
     """
     This functions checks the authorizations from the current HTTP call.
@@ -81,7 +83,7 @@ def check_access_rights(service: str,
                         return {'detail': 'You don\'t have access to Adscale resources\n', 'firebase_log': str(e)}, 401
 
                 try:
-                    send_tracking_information(claims['email'], service, job_func.__name__, project, adscale_key,
+                    send_tracking_information(claims['email'], service, job_func.__name__, project,
                                               pubsub_client, datastore_client)
                 except KeyError:
                     adscale_log(ServiceEnum.TRACKING, f'The user email is not contained in the claims')
@@ -102,7 +104,7 @@ def check_access_rights(service: str,
                 if ALL_CLIENTS_RIGHTS in authorized_clients:
                     authorized_clients.remove(ALL_CLIENTS_RIGHTS)
                     clients_query = datastore_client.query()
-                    clients_query.kind = clients_kind
+                    clients_query.kind = CLIENTS_KIND
                     clients_query.keys_only()
                     authorized_clients.extend(
                         [client_entity.key.name for client_entity in clients_query.fetch()
