@@ -14,7 +14,7 @@ from arcane.pubsub import Client as PubSubClient
 PUBSUB_ACTIVITY_TRACKING_TOPIC = 'activity-tracker'
 
 
-def send_tracking_information(email: str, service: str, function_name: str, project: str, adscale_key: str,
+def send_tracking_information(email: str, service: str, function_name: str, project: str,
                               pubsub_client: PubSubClient, datastore_client: DatastoreClient) -> None:
     """ Send pubsub message to the tracking cloud function"""
 
@@ -27,13 +27,12 @@ def send_tracking_information(email: str, service: str, function_name: str, proj
         insert_id = str(uuid.uuid4())
 
         pubsub_client.push_to_topic(
-            project,
-            PUBSUB_ACTIVITY_TRACKING_TOPIC,
-            {'user_email': email,
+            project=project,
+            topic_name=PUBSUB_ACTIVITY_TRACKING_TOPIC,
+            parameters={'user_email': email,
              'service': service,
              'timestamp': timestamp,
              'function_name': function_name,
              'insert_id': insert_id
-             },
-            adscale_key
+             }
         )
